@@ -1,10 +1,10 @@
 # frozen_string_literal: true
 
-require_relative '../lib/tty-command'
+require_relative "../lib/tty-command"
 
 cmd = TTY::Command.new
 
-f = 'file'
+f = "file"
 if cmd.test("[ -f #{f} ]")
   puts "#{f} already exists!"
 else
