@@ -1,23 +1,19 @@
-# encoding: utf-8
-
-require_relative 'abstract'
+require_relative "abstract"
 
 module TTY
   class Command
     module Printers
       class Quiet < Abstract
-        attr_reader :output, :options
-
         def print_command_start(cmd)
           # quiet
         end
 
         def print_command_out_data(cmd, *args)
-          write(cmd, args.join(' '), out_data)
+          write(cmd, args.join(" "), out_data)
         end
 
         def print_command_err_data(cmd, *args)
-          write(cmd, args.join(' '), err_data)
+          write(cmd, args.join(" "), err_data)
         end
 
         def print_command_exit(cmd, status, *args)
