@@ -1,8 +1,8 @@
 # frozen_string_literal: true
 
-RSpec.describe TTY::Command::ExitError, 'info' do
+RSpec.describe TTY::Command::ExitError, "info" do
   it "displays stdin & stdout" do
-    result = double(exit_status: 157, out: 'out content', err: 'err content')
+    result = double(exit_status: 157, out: "out content", err: "err content")
     error = described_class.new(:cat, result)
     expect(error.message).to eq([
       "Running `cat` failed with\n",
@@ -13,7 +13,7 @@ RSpec.describe TTY::Command::ExitError, 'info' do
   end
 
   it "explains no stdin & stdout" do
-    result = double(exit_status: 157, out: '', err: '')
+    result = double(exit_status: 157, out: "", err: "")
     error = described_class.new(:cat, result)
     expect(error.message).to eq([
       "Running `cat` failed with\n",
