@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 RSpec.describe TTY::Command::Printers::Null do
   let(:output) { StringIO.new }
@@ -18,7 +18,7 @@ RSpec.describe TTY::Command::Printers::Null do
     printer = TTY::Command::Printers::Null.new(output)
     cmd = TTY::Command::Cmd.new("echo hello")
 
-    printer.print_command_out_data(cmd, 'hello', 'world')
+    printer.print_command_out_data(cmd, "hello", "world")
     output.rewind
 
     expect(output.string).to be_empty
@@ -28,7 +28,7 @@ RSpec.describe TTY::Command::Printers::Null do
     printer = TTY::Command::Printers::Null.new(output)
     cmd = TTY::Command::Cmd.new("echo hello")
 
-    printer.print_command_err_data(cmd, 'hello', 'world')
+    printer.print_command_err_data(cmd, "hello", "world")
     output.rewind
 
     expect(output.string).to be_empty
